ChatListModal class

Constructors

ChatListModal({required String lastMessage, required String lastMessageType, required Timestamp updatedAt, required Timestamp createdAt, required List users, required DocumentSnapshot<Object?> snapshot, required Map fullData, required GroupChatDetails? groupChatDetails, required bool isGroup, required Map<String, ChatUserModal> involvedUserModals})
ChatListModal.fromJson(DocumentSnapshot<Object?> snapshot)
factory

Properties

createdAt ↔ Timestamp
getter/setter pair
fullData ↔ Map
getter/setter pair
groupChatDetails ↔ GroupChatDetails?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
involvedUserModals ↔ Map<String, ChatUserModal>
getter/setter pair
isGroup ↔ bool
getter/setter pair
lastMessage ↔ String
getter/setter pair
lastMessageType ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
snapshot ↔ DocumentSnapshot<Object?>
getter/setter pair
updatedAt ↔ Timestamp
getter/setter pair
users ↔ List
getter/setter pair

Methods

buildProfileImage(String currentUserId, String initials, {double size = 60}) → Widget
getName(String currentUserId) → String
getProfileImage(String currentUserId) → String?
getUnreadCount(String userId) → dynamic
getUserData(String userId) → ChatUserModal
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited